@@ -68,6 +68,36 @@ def export_files_to_output_folder(
         ],
     )
 
+    formular = "x(centroid(transform($geometry,'%s','%s')))" % (
+        layer_cat.crs().authid(),
+        "EPSG:4326",
+    )
+
+    layer_cat = qgis_vector_field_calculator(
+        processing=processing,
+        context=context,
+        FORMULA=formular,
+        FIELD_NAME="centroid_x",
+        INPUT=layer_cat,
+        OUTPUT="memory:",
+    )["OUTPUT"]
+        
+
+    formular = "y(centroid(transform($geometry,'%s','%s')))" % (
+        layer_cat.crs().authid(),
+        "EPSG:4326",
+    )
+
+    layer_cat = qgis_vector_field_calculator(
+        processing=processing,
+        context=context,
+        FORMULA=formular,
+        FIELD_NAME="centroid_y",
+        INPUT=layer_cat,
+        OUTPUT="memory:",
+    )["OUTPUT"]
+
+
     Selectfeatureattributes(
         processing,
         Input=layer_cat,
@@ -94,9 +124,9 @@ def export_files_to_output_folder(
                  os.path.join(output_folder, output_riv + ".shp")
     )
     
-    Add_centroid_to_feature(
-        os.path.join(output_folder, output_cat + ".shp"), "centroid_x", "centroid_y"
-    )
+    # Add_centroid_to_feature(
+    #     os.path.join(output_folder, output_cat + ".shp"), "centroid_x", "centroid_y"
+    # )
 
     subinfo = Dbf_To_Dataframe(os.path.join(output_folder, output_cat + ".shp"))
 
@@ -123,7 +153,7 @@ def export_files_to_output_folder(
 
     if (
         os.path.exists(os.path.join(grassdb, snapped_obs_points + ".shp"))
-        and len(subinfo.loc[subinfo["Has_Gauge"] > 0]["Has_Gauge"].values) > 0
+        and len(subinfo.loc[subinfo["Has_POI"] > 0]["Has_POI"].values) > 0
     ):
 
         Selectfeatureattributes(
@@ -131,15 +161,15 @@ def export_files_to_output_folder(
             Input=os.path.join(grassdb, snapped_obs_points + ".shp"),
             Output=os.path.join(output_folder, "obs_gauges.shp"),
             Attri_NM=obs_attributes[1],
-            Values=subinfo.loc[subinfo["Has_Gauge"] > 0]["Obs_NM"].values,
+            Values=subinfo.loc[subinfo["Has_POI"] > 0]["Obs_NM"].values,
             Is_str = True,
         )
 
     Clean_Attribute_Name(
-        os.path.join(output_folder, output_cat + ".shp"), COLUMN_NAMES_CONSTANT
+        os.path.join(output_folder, output_cat + ".shp"), COLUMN_NAMES_CONSTANT_CLEAN
     )
     Clean_Attribute_Name(
-        os.path.join(output_folder, output_riv + ".shp"), COLUMN_NAMES_CONSTANT
+        os.path.join(output_folder, output_riv + ".shp"), COLUMN_NAMES_CONSTANT_CLEAN
     )
 
     return
