@@ -103,6 +103,7 @@ class postprocess:
             EndYear=endYear,
             CA_HYDAT=CA_HYDAT,
             WarmUp=warmup,
+            time_step = model_time_step,
             Template_Folder=template_folder,
             Lake_As_Gauge=lake_as_gauge,
             WriteObsrvt=writeobsrvt,
@@ -116,6 +117,7 @@ class postprocess:
             OutputFolder=path_output_folder,
             Forcing_Input_File=forcing_input_file,
             aspect_from_gis = aspect_from_gis,
+            lake_out_flow_method = lake_out_flow_method,
         )
 
 
@@ -517,9 +519,11 @@ class postprocess:
         path_vegetation_polygon="#",
         path_other_polygon_1="#",
         path_other_polygon_2="#",
-        inmportance_order = [],
+        importance_order = [],
         min_hru_subbasin_area_ratio = 0.0,
         path_to_dem="#",
+        pixel_size = 30,
+        area_ratio_thresholds = [0,0,0]
     ):
         """This function is to generate HRU map based on subbasin polygon, lake 
         polygon (optional), Land use polygon (optional), soil type polygon(optional),
@@ -636,12 +640,14 @@ class postprocess:
             Path_Other_Ply_2=path_other_polygon_2,
             Other_Ply_ID_2=Other_Ply_ID_2,
             DEM=path_to_dem,
-            Inmportance_order = inmportance_order,
+            Inmportance_order = importance_order,
             min_hru_area_pct_sub = min_hru_subbasin_area_ratio,
             Project_crs=projected_epsg_code,
             OutputFolder=path_output_folder,
             qgis_prefix_path=self.qgispp,
             gis_platform = gis_platform,
+            pixel_size = pixel_size,
+            area_ratio_thresholds = area_ratio_thresholds,
         )
 
 
@@ -907,7 +913,7 @@ class delineate:
             input_geo_names=self.geofilenames,
             acc_thresold=fac_thresold,
             fdr_path=path_flow_dirction,
-#            fac_path = path_flow_accumulation,
+            fac_path = path_flow_accumulation,
             subreg_fdr_path=subreg_fdr_path,
             subreg_acc_path=subreg_acc_path,
             subreg_str_r_path=subreg_str_r_path,
