@@ -11,8 +11,40 @@ from basinmaker.utilities.utilities import *
 import tempfile
 from json import load, JSONEncoder
 import json
+import shutil
+
+def qgis_raster_gdal_warpreproject(processing, Input, TARGET_CRS, Output):
+    """Functions reproject raster layer
+    ----------
+
+    Notes
+    -------
+
+    Returns:
+    -------
+        None, the attribute table of Path_shpfile will be updated
+    """
+
+    out = processing.run(
+        "gdal:warpreproject",
+        {
+            "INPUT": Input,
+            "SOURCE_CRS": None,
+            "TARGET_CRS": QgsCoordinateReferenceSystem(TARGET_CRS),
+            "RESAMPLING": 0,
+            "NODATA": None,
+            "TARGET_RESOLUTION": None,
+            "OPTIONS": "",
+            "DATA_TYPE": 0,
+            "TARGET_EXTENT": None,
+            "TARGET_EXTENT_CRS": None,
+            "MULTITHREADING": False,
+            "EXTRA": "",
+            "OUTPUT": Output,
+        },
+    )
+    return out
 
-####
 ####
 def create_geo_jason_file(processing,Input_Polygon_path):
 
@@ -21,7 +53,7 @@ def create_geo_jason_file(processing,Input_Polygon_path):
     Names_in = os.path.basename(Input_Polygon_path).split('_')
     n_charc = len(Names_in)
     version  = Names_in[n_charc - 1][0:4]
-    TOLERANCEs = [0.0001,0.0005,0.001,0.005,0.01,0.05,0.1]
+    TOLERANCEs = [0.0001,0.0005,0.001,0.005,0.01,0.05]
 
 
     head_name_cat = "finalcat_info"
@@ -58,13 +90,18 @@ def create_geo_jason_file(processing,Input_Polygon_path):
                            head_name_nlake +'.geojson',
                            ]
     created_jason_files = []   
-
+    created_jason_files_lake_riv = [] 
+    
     for i  in  range(0,len(Input_file_name)):
         input_path = os.path.join(product_dir,Input_file_name[i])
         output_jason_path = os.path.join(product_dir,Output_file_name[i])
         if not os.path.exists(input_path):
             continue 
-        created_jason_files.append(output_jason_path)                   
+        created_jason_files.append(output_jason_path) 
+        
+        if 'finalcat_info_riv' in Input_file_name[i] or 'connected_lake' in Input_file_name[i]:
+            created_jason_files_lake_riv.append(output_jason_path)  
+                            
         # reproject to WGS84
         input_wgs_84 = processing.run("native:reprojectlayer", {'INPUT':input_path,
                                       'TARGET_CRS':QgsCoordinateReferenceSystem('EPSG:4326'),
@@ -80,7 +117,7 @@ def create_geo_jason_file(processing,Input_Polygon_path):
                                                       'FIELD_NAME':'rvhName','FIELD_TYPE':2,'FIELD_LENGTH':20,'FIELD_PRECISION':0,
                                                       'FORMULA':'\'sub\' +to_string(to_int(\"SubId\")) ','OUTPUT':"memory:"})['OUTPUT']
         else:
-             input_tojson = input_tojson
+             input_tojson = input_wgs_84
         
         for TOLERANCE in TOLERANCEs:                               
             input_wgs_84_simplify = processing.run("native:simplifygeometries", {
@@ -94,233 +131,42 @@ def create_geo_jason_file(processing,Input_Polygon_path):
             qgis.core.QgsVectorFileWriter.writeAsVectorFormat(input_wgs_84_simplify,output_jason_path, 'utf-8', input_wgs_84_simplify.crs(), 'GeoJson',layerOptions=['COORDINATE_PRECISION=3'])
             
             json_file_size = os.stat(output_jason_path).st_size/1024/1024 #to MB
-            if json_file_size <= 20:
+            if json_file_size <= 100:
                 break
-    if len(created_jason_files) > 1:
-        for i in range(0,len(created_jason_files)):
-            injson = load(open(created_jason_files[i]))
+    # if len(created_jason_files) > 1 and os.stat(os.path.join(product_dir,Output_file_name[0])).st_size/1024/1024 < 500::
+    #     for i in range(0,len(created_jason_files)):
+    #         injson = load(open(created_jason_files[i]))
+    #         if i == 0:
+    #             output_jason = injson
+    #         else:
+    #             output_jason['features'] += injson['features']
+    # 
+    #     with open(os.path.join(product_dir,'routing_product.geojson'), 'w', encoding='utf-8') as f:
+    #         json.dump(output_jason, f, ensure_ascii=False, indent=4)
+    # else:
+    #     shutil.copy(created_jason_files[0], os.path.join(product_dir,'routing_product.geojson')) 
+        
+    if len(created_jason_files_lake_riv) > 1 and os.stat(os.path.join(product_dir,Output_file_name[0])).st_size/1024/1024 < 500:
+        for i in range(0,len(created_jason_files_lake_riv)):
+            injson2 = load(open(created_jason_files_lake_riv[i]))
+            if 'finalcat_info_riv' in created_jason_files_lake_riv[i]:
+                new_features = []
+                for element in injson2["features"]:
+                    if element["properties"]["Lake_Cat"] == 0:    
+                        new_features.append(element) 
+                injson2["features"] = new_features
+
             if i == 0:
-                output_jason = injson
+                output_jason_lake_riv = injson2
             else:
-                output_jason['features'] += injson['features']
+                output_jason_lake_riv['features'] += injson2['features']
                 
-        with open(os.path.join(product_dir,'routing_product.geojson'), 'w', encoding='utf-8') as f:
-            json.dump(output_jason, f, ensure_ascii=False, indent=4)
-     
-    return 
-    
-##############
-
-
-def copy_data_and_dissolve(all_subids,tempfolder,processing,Path_Temp_final_rviply,Path_Temp_final_rvi,
-    mapoldnew_info,COLUMN_NAMES_CONSTANT_CLEAN,OutputFolder,Path_Catchment_Polygon,context,Path_final_rviply_input = '#',Path_final_rvi_input = '#'):    
-    
-    if len(all_subids) > 5000:
-
-        Path_final_rviply = os.path.join(
-            tempfolder,
-            "temp_finalriv_ply"  + ".shp",
-        )
-        Path_final_rvi = os.path.join(
-            tempfolder,
-            "temp_finalriv"  + ".shp",
-        )
-    
-        Copy_Pddataframe_to_shpfile_main(
-            Path_shpfile = Path_Temp_final_rviply,
-            Pddataframe = mapoldnew_info,
-            all_subids = all_subids,
-            tempfolder = tempfolder,
-            processing = processing,
-            output = Path_final_rviply,
-            link_col_nm_shp="SubId",
-            link_col_nm_df="Old_SubId",
-            UpdateColNM=["#"],
-        )  
-        
-        Copy_Pddataframe_to_shpfile_main(
-            Path_shpfile = Path_Temp_final_rvi,
-            Pddataframe = mapoldnew_info,
-            all_subids = all_subids,
-            tempfolder = tempfolder,
-            processing = processing,  
-            output =   Path_final_rvi,    
-            link_col_nm_shp="SubId",
-            link_col_nm_df="Old_SubId",
-            UpdateColNM=["#"],
-        )    
-                              
+        with open(os.path.join(product_dir,'routing_product_lake_river.geojson'), 'w', encoding='utf-8') as f:
+            json.dump(output_jason_lake_riv, f, ensure_ascii=False, indent=4)
     else:
-            
-        Path_final_rviply = Path_Temp_final_rviply
-        Path_final_rvi = Path_Temp_final_rvi
-                    
-        Copy_Pddataframe_to_shpfile(
-            Path_Temp_final_rviply,
-            mapoldnew_info,
-            link_col_nm_shp="SubId",
-            link_col_nm_df="Old_SubId",
-            UpdateColNM=["#"],
-        )
-        Copy_Pddataframe_to_shpfile(
-            Path_Temp_final_rvi,
-            mapoldnew_info,
-            link_col_nm_shp="SubId",
-            link_col_nm_df="Old_SubId",
-            UpdateColNM=["#"],
-        )
-
-    # dissolve shpfile based on new subid
-    if len(os.path.basename(Path_Catchment_Polygon).split('_')) == 5:
-        Path_final_rviply_out = os.path.join(OutputFolder, "finalcat_info_"+os.path.basename(Path_Catchment_Polygon).split('_')[4])
-        Path_final_rvi_out = os.path.join(OutputFolder, "finalcat_info_riv_"+os.path.basename(Path_Catchment_Polygon).split('_')[4])
-    else:
-        Path_final_rviply_out = os.path.join(OutputFolder, "finalcat_info.shp")
-        Path_final_rvi_out = os.path.join(OutputFolder, "finalcat_info_riv.shp")
-
-    if Path_final_rviply_input != '#' and Path_final_rvi_input != '#':
-        Path_final_rviply_out = os.path.join(OutputFolder, os.path.basename(Path_final_rviply_input))
-        Path_final_rvi_out = os.path.join(OutputFolder, os.path.basename(Path_final_rvi_input))
-        
-                
-    Clean_Attribute_Name(Path_final_rvi, COLUMN_NAMES_CONSTANT_CLEAN)
-    Clean_Attribute_Name(Path_final_rviply, COLUMN_NAMES_CONSTANT_CLEAN)
-    
-                    
-    qgis_vector_dissolve(
-        processing,
-        context,
-        INPUT=Path_final_rvi,
-        FIELD=["SubId"],
-        OUTPUT=Path_final_rvi_out,
-    )
-    ply_draft = qgis_vector_dissolve(
-        processing,
-        context,
-        INPUT=Path_final_rviply,
-        FIELD=["SubId"],
-        OUTPUT="memory:",
-    )["OUTPUT"]
-    
-    # clean attribute table of shpfile
-    Clean_Attribute_Name(Path_final_rvi_out, COLUMN_NAMES_CONSTANT_CLEAN)
-    ply_draft,tempnum = Clean_Attribute_Name(ply_draft, COLUMN_NAMES_CONSTANT_CLEAN,Input_Is_Feature_In_Mem = True)
-
-    # add centroid to new drived polygons
-    
-    formular = "x(centroid(transform($geometry,'%s','%s')))" % (
-        ply_draft.crs().authid(),
-        "EPSG:4326",
-    )
-
-    ply_draft = qgis_vector_field_calculator(
-        processing=processing,
-        context=context,
-        FORMULA=formular,
-        FIELD_NAME="centroid_x",
-        INPUT=ply_draft,
-        OUTPUT="memory:",
-    )["OUTPUT"]
-
-    formular = "y(centroid(transform($geometry,'%s','%s')))" % (
-        ply_draft.crs().authid(),
-        "EPSG:4326",
-    )
-
-    qgis_vector_field_calculator(
-        processing=processing,
-        context=context,
-        FORMULA=formular,
-        FIELD_NAME="centroid_y",
-        INPUT=ply_draft,
-        OUTPUT=Path_final_rviply_out,
-    )
-    if 'finalcat_info' in Path_final_rviply_out:
-        create_geo_jason_file(processing,Path_final_rviply_out)
+        shutil.copy(created_jason_files_lake_riv[0], os.path.join(product_dir,'routing_product_lake_river.geojson'))             
     return 
-
-
-def Copy_Pddataframe_to_shpfile_main(
-    Path_shpfile,
-    Pddataframe,
-    all_subids,
-    tempfolder,
-    processing,
-    output,
-    link_col_nm_shp="SubId",
-    link_col_nm_df="SubId",
-    UpdateColNM=["#"],
-    Input_Is_Feature_In_Mem=False,
-):
-
-    path_to_temp_files = []
-    ncores = 3
-    feature_per_file = int(len(all_subids)/ncores)
     
-    for i in range(0,ncores):
-        num_random = str(np.random.randint(1, 10000 + 1)) +'_'+str(i)
-        path_of_i_temp_file = os.path.join(
-            tempfolder,
-            "temp_finalriv_ply" + num_random + ".shp",
-        )
-        if i != ncores - 1:
-            subids_of_i_temp_file = all_subids[i*feature_per_file:(i+1)*feature_per_file]
-        else:
-            subids_of_i_temp_file = all_subids[i*feature_per_file:len(all_subids)]
-                
-        Selectfeatureattributes(
-            processing,
-            Input=Path_shpfile,
-            Output=path_of_i_temp_file,
-            Attri_NM="SubId",
-            Values=subids_of_i_temp_file,
-        )
-        path_to_temp_files.append(path_of_i_temp_file)
-
-    print(path_to_temp_files)
-    Parallel(n_jobs=ncores, verbose=1, backend="threading")(
-        delayed(Copy_Pddataframe_to_shpfile)(temp_file,Pddataframe,
-        link_col_nm_shp="SubId",link_col_nm_df="Old_SubId",UpdateColNM=["#"]
-        ) for temp_file in path_to_temp_files)
-    
-    processing.run("native:mergevectorlayers", {'LAYERS':path_to_temp_files,'CRS':None,'OUTPUT':output})
-    
-    return 
-
-
-def qgis_raster_gdal_warpreproject(processing, Input, TARGET_CRS, Output):
-    """Functions reproject raster layer
-    ----------
-
-    Notes
-    -------
-
-    Returns:
-    -------
-        None, the attribute table of Path_shpfile will be updated
-    """
-
-    out = processing.run(
-        "gdal:warpreproject",
-        {
-            "INPUT": Input,
-            "SOURCE_CRS": None,
-            "TARGET_CRS": QgsCoordinateReferenceSystem(TARGET_CRS),
-            "RESAMPLING": 0,
-            "NODATA": None,
-            "TARGET_RESOLUTION": None,
-            "OPTIONS": "",
-            "DATA_TYPE": 0,
-            "TARGET_EXTENT": None,
-            "TARGET_EXTENT_CRS": None,
-            "MULTITHREADING": False,
-            "EXTRA": "",
-            "OUTPUT": Output,
-        },
-    )
-    return out
-
-
 ##############
 
 
@@ -586,6 +432,28 @@ def qgis_raster_gdal_rasterize(
 
 # os.system('gdal_rasterize -at -of GTiff -a_nodata -9999 -a Hylak_id -tr  '+ str(self.cellSize) + "  " +str(self.cellSize)+'  -te   '+ str(grsregion['w'])+"   " +str(grsregion['s'])+"   " +str(grsregion['e'])+"   " +str(grsregion['n'])+"   " + "\"" +  self.Path_allLakeply +"\""+ "    "+ "\""+self.Path_allLakeRas+"\"")
 
+def Copy_Pddataframe_to_shpfile_by_file(
+    Path_shpfile,
+    Pddataframe,
+    link_col_nm_shp="SubId",
+    link_col_nm_df="SubId",
+    UpdateColNM=["#"],
+    Input_Is_Feature_In_Mem=False,
+):
+
+    if Input_Is_Feature_In_Mem:
+        layer_cat = Path_shpfile
+    else:
+        layer_cat = QgsVectorLayer(Path_shpfile, "")
+    
+    # table to csv 
+    Attri_table.to_csv(os.path.join(tempfile.gettempdir(), "attribute.csv"),index = False)
+    csv_uri = 'file:///%s?delimiter=,'%(os.path.join(tempfile.gettempdir(), "attribute.csv"))
+    csv = QgsVectorLayer(csv_uri, 'attributes', 'delimitedtext')
+
+    
+    
+
 
 def Copy_Pddataframe_to_shpfile(
     Path_shpfile,
@@ -621,7 +489,7 @@ def Copy_Pddataframe_to_shpfile(
         layer_cat = Path_shpfile
     else:
         layer_cat = QgsVectorLayer(Path_shpfile, "")
-
+        
     Attri_Name = layer_cat.fields().names()
     features = layer_cat.getFeatures()
     with edit(layer_cat):
@@ -685,6 +553,188 @@ def Copy_Pddataframe_to_shpfile(
         del layer_cat
         return
 
+def copy_data_and_dissolve(all_subids,tempfolder,processing,Path_Temp_final_rviply,Path_Temp_final_rvi,
+    mapoldnew_info,COLUMN_NAMES_CONSTANT_CLEAN,OutputFolder,Path_Catchment_Polygon,context,Path_final_rviply_input = '#',Path_final_rvi_input = '#'):    
+    
+    if len(all_subids) > 5000:
+
+        Path_final_rviply = os.path.join(
+            tempfolder,
+            "temp_finalriv_ply"  + ".shp",
+        )
+        Path_final_rvi = os.path.join(
+            tempfolder,
+            "temp_finalriv"  + ".shp",
+        )
+    
+        Copy_Pddataframe_to_shpfile_main(
+            Path_shpfile = Path_Temp_final_rviply,
+            Pddataframe = mapoldnew_info,
+            all_subids = all_subids,
+            tempfolder = tempfolder,
+            processing = processing,
+            output = Path_final_rviply,
+            link_col_nm_shp="SubId",
+            link_col_nm_df="Old_SubId",
+            UpdateColNM=["#"],
+        )  
+        
+        Copy_Pddataframe_to_shpfile_main(
+            Path_shpfile = Path_Temp_final_rvi,
+            Pddataframe = mapoldnew_info,
+            all_subids = all_subids,
+            tempfolder = tempfolder,
+            processing = processing,  
+            output =   Path_final_rvi,    
+            link_col_nm_shp="SubId",
+            link_col_nm_df="Old_SubId",
+            UpdateColNM=["#"],
+        )    
+                              
+    else:
+            
+        Path_final_rviply = Path_Temp_final_rviply
+        Path_final_rvi = Path_Temp_final_rvi
+                    
+        Copy_Pddataframe_to_shpfile(
+            Path_Temp_final_rviply,
+            mapoldnew_info,
+            link_col_nm_shp="SubId",
+            link_col_nm_df="Old_SubId",
+            UpdateColNM=["#"],
+        )
+        Copy_Pddataframe_to_shpfile(
+            Path_Temp_final_rvi,
+            mapoldnew_info,
+            link_col_nm_shp="SubId",
+            link_col_nm_df="Old_SubId",
+            UpdateColNM=["#"],
+        )
+
+    # dissolve shpfile based on new subid
+    if len(os.path.basename(Path_Catchment_Polygon).split('_')) == 5:
+        Path_final_rviply_out = os.path.join(OutputFolder, "finalcat_info_"+os.path.basename(Path_Catchment_Polygon).split('_')[4])
+        Path_final_rvi_out = os.path.join(OutputFolder, "finalcat_info_riv_"+os.path.basename(Path_Catchment_Polygon).split('_')[4])
+    else:
+        Path_final_rviply_out = os.path.join(OutputFolder, "finalcat_info.shp")
+        Path_final_rvi_out = os.path.join(OutputFolder, "finalcat_info_riv.shp")
+
+    if Path_final_rviply_input != '#' and Path_final_rvi_input != '#':
+        Path_final_rviply_out = os.path.join(OutputFolder, os.path.basename(Path_final_rviply_input))
+        Path_final_rvi_out = os.path.join(OutputFolder, os.path.basename(Path_final_rvi_input))
+        
+    COLUMN_NAMES_CONSTANT_CLEAN_RIV = COLUMN_NAMES_CONSTANT_CLEAN.copy()
+    COLUMN_NAMES_CONSTANT_CLEAN_RIV.remove('centroid_x') 
+    COLUMN_NAMES_CONSTANT_CLEAN_RIV.remove('centroid_y')  
+    Clean_Attribute_Name(Path_final_rvi, COLUMN_NAMES_CONSTANT_CLEAN_RIV)
+    Clean_Attribute_Name(Path_final_rviply, COLUMN_NAMES_CONSTANT_CLEAN)
+    
+                    
+    riv_dissolve = qgis_vector_dissolve(
+        processing,
+        context,
+        INPUT=Path_final_rvi,
+        FIELD=["SubId"],
+        OUTPUT="memory:",# Path_final_rvi_out,
+    )["OUTPUT"]
+
+    processing.run("native:extractbyexpression", {
+                    'INPUT':riv_dissolve,
+                    'EXPRESSION':' \"Lake_Cat\" > 0  OR  \"RivLength\" > 0',
+                    'OUTPUT':Path_final_rvi_out}
+                    )
+
+    ply_draft = qgis_vector_dissolve(
+        processing,
+        context,
+        INPUT=Path_final_rviply,
+        FIELD=["SubId"],
+        OUTPUT="memory:",
+    )["OUTPUT"]
+    
+    # clean attribute table of shpfile
+    Clean_Attribute_Name(Path_final_rvi_out, COLUMN_NAMES_CONSTANT_CLEAN)
+    ply_draft,tempnum = Clean_Attribute_Name(ply_draft, COLUMN_NAMES_CONSTANT_CLEAN,Input_Is_Feature_In_Mem = True)
+
+    # add centroid to new drived polygons
+    
+    formular = "x(centroid(transform($geometry,'%s','%s')))" % (
+        ply_draft.crs().authid(),
+        "EPSG:4326",
+    )
+
+    ply_draft = qgis_vector_field_calculator(
+        processing=processing,
+        context=context,
+        FORMULA=formular,
+        FIELD_NAME="centroid_x",
+        INPUT=ply_draft,
+        OUTPUT="memory:",
+    )["OUTPUT"]
+
+    formular = "y(centroid(transform($geometry,'%s','%s')))" % (
+        ply_draft.crs().authid(),
+        "EPSG:4326",
+    )
+
+    qgis_vector_field_calculator(
+        processing=processing,
+        context=context,
+        FORMULA=formular,
+        FIELD_NAME="centroid_y",
+        INPUT=ply_draft,
+        OUTPUT=Path_final_rviply_out,
+    )
+    if 'finalcat_info' in Path_final_rviply_out:
+        create_geo_jason_file(processing,Path_final_rviply_out)
+    return 
+
+def Copy_Pddataframe_to_shpfile_main(
+    Path_shpfile,
+    Pddataframe,
+    all_subids,
+    tempfolder,
+    processing,
+    output,
+    link_col_nm_shp="SubId",
+    link_col_nm_df="SubId",
+    UpdateColNM=["#"],
+    Input_Is_Feature_In_Mem=False,
+):
+
+    path_to_temp_files = []
+    ncores = 3
+    feature_per_file = int(len(all_subids)/ncores)
+    
+    for i in range(0,ncores):
+        num_random = str(np.random.randint(1, 10000 + 1)) +'_'+str(i)
+        path_of_i_temp_file = os.path.join(
+            tempfolder,
+            "temp_finalriv_ply" + num_random + ".shp",
+        )
+        if i != ncores - 1:
+            subids_of_i_temp_file = all_subids[i*feature_per_file:(i+1)*feature_per_file]
+        else:
+            subids_of_i_temp_file = all_subids[i*feature_per_file:len(all_subids)]
+                
+        Selectfeatureattributes(
+            processing,
+            Input=Path_shpfile,
+            Output=path_of_i_temp_file,
+            Attri_NM="SubId",
+            Values=subids_of_i_temp_file,
+        )
+        path_to_temp_files.append(path_of_i_temp_file)
+
+    Parallel(n_jobs=ncores, verbose=1, backend="threading")(
+        delayed(Copy_Pddataframe_to_shpfile)(temp_file,Pddataframe,
+        link_col_nm_shp="SubId",link_col_nm_df="Old_SubId",UpdateColNM=["#"]
+        ) for temp_file in path_to_temp_files)
+    
+    processing.run("native:mergevectorlayers", {'LAYERS':path_to_temp_files,'CRS':None,'OUTPUT':output})
+    
+    return 
+    
 
 def Remove_Unselected_Lake_Attribute_In_Finalcatinfo(Path_Finalcatinfo, Conn_Lake_Ids):
     """Functions will set lake id not in Conn_Lake_Ids to -1.2345 in attribute
@@ -772,10 +822,21 @@ def Selectfeatureattributes(processing, Input="#", Output="#", Attri_NM="#", Val
             exp =  exp + " , \'%s\'" %(Values[i])
         exp = exp + ")"
     else:
+        ncores = 3
+        nvalues_per_group = 1000
+        k = 0
         exp = Attri_NM + "  IN  (  " + str(int(Values[0]))
         for i in range(1, len(Values)):
-            exp = exp + " , " + str(int(Values[i]))
+            k = k + 1
+            if k != 0:
+                exp = exp + " , " + str(int(Values[i]))
+            if k == nvalues_per_group and k < len(Values) - 3:
+                k = 0
+                exp = exp + ")"
+                exp = exp + ' OR ' + Attri_NM + "  IN  (  " + str(int(Values[i]))
+        
         exp = exp + ")"
+    
     processing.run(
         "native:extractbyexpression",
         {"INPUT": Input, "EXPRESSION": exp, "OUTPUT": Output},
@@ -1327,27 +1388,39 @@ def Obtain_Attribute_Table(
     Attri_Tbl                  : Dataframe
        The attribute table in the input vector layer
     """
-
+    
     if Input_Is_Feature_In_Mem:
-        vec_layer = input_layer
+        
+        output_layer = os.path.join(tempfile.gettempdir(),'basinmaker_layer_'+str(np.random.randint(1, 10000 + 1))+".shp")
+        
+        _writer = QgsVectorFileWriter.writeAsVectorFormat(
+        input_layer,
+        output_layer,
+        'utf-8',
+        driverName='ESRI Shapefile'
+        )
+        vec_layer = output_layer
+
     else:
-        vec_layer = QgsVectorLayer(input_layer, "")
+        vec_layer = input_layer
+    
+    Attri_Tbl = Dbf_To_Dataframe(vec_layer)
 
-    N_new_features = vec_layer.featureCount()
-    field_names = []
-    for field in vec_layer.fields():
-        field_names.append(field.name())
-    Attri_Tbl = pd.DataFrame(
-        data=np.full((N_new_features, len(field_names)), np.nan), columns=field_names
-    )
-
-    src_features = vec_layer.getFeatures()
-    i_sf = 0
-    for sf in src_features:
-        for field in vec_layer.fields():
-            filednm = field.name()
-            Attri_Tbl.loc[Attri_Tbl.index[i_sf], filednm] = sf[filednm]
-        i_sf = i_sf + 1
+    # N_new_features = vec_layer.featureCount()
+    # field_names = []
+    # for field in vec_layer.fields():
+    #     field_names.append(field.name())
+    # Attri_Tbl = pd.DataFrame(
+    #     data=np.full((N_new_features, len(field_names)), np.nan), columns=field_names
+    # )
+    # 
+    # src_features = vec_layer.getFeatures()
+    # i_sf = 0
+    # for sf in src_features:
+    #     for field in vec_layer.fields():
+    #         filednm = field.name()
+    #         Attri_Tbl.loc[Attri_Tbl.index[i_sf], filednm] = sf[filednm]
+    #     i_sf = i_sf + 1
     return Attri_Tbl
 
 
