@@ -18,6 +18,7 @@ def GenerateRavenInput(
     EndYear=-1,
     CA_HYDAT="#",
     WarmUp=0,
+    time_step = 1,
     Template_Folder="#",
     Lake_As_Gauge=False,
     WriteObsrvt=False,
@@ -30,7 +31,8 @@ def GenerateRavenInput(
     SubBasinGroup_Area_Lake=[-1],
     OutputFolder="#",
     Forcing_Input_File="#",
-    aspect_from_gis = 'grass'
+    aspect_from_gis = 'grass',
+    lake_out_flow_method = 'broad_crest',
 ):
 
     """Generate Raven input files.
@@ -213,10 +215,11 @@ def GenerateRavenInput(
     ncatinfo = tempinfo.to_dataframe()
     ncatinfo2 = ncatinfo.drop_duplicates("HRU_ID", keep="first")
     ncatinfo2 = ncatinfo2.loc[(ncatinfo2["HRU_ID"] > 0) & (ncatinfo2["SubId"] > 0)]
-	
+    
     if 'DrainArea' in ncatinfo2.columns:
-        ncatinfo2 = ncatinfo2.sort_values(by=['DrainArea','HRU_ID'])		
-    if Old_Product == True:
+        ncatinfo2 = ncatinfo2.sort_values(by=['DrainArea','HRU_ID'])
+    
+    if 'Rivlen' in ncatinfo2.columns:
         ncatinfo2["RivLength"] = ncatinfo2["Rivlen"].values
     #            ncatinfo2['RivSlope'] = ncatinfo2['Rivlen'].values
     #            ncatinfo2['RivLength'] = ncatinfo2['Rivlen'].values
@@ -240,15 +243,17 @@ def GenerateRavenInput(
         SubBasinGroup_Area_Lake,
         SubBasinGroup_NM_Channel,
         SubBasinGroup_Length_Channel,
+        time_step,
         aspect_from_gis
     )
     WriteStringToFile(Channel_rvp_string + '\n \n', Channel_rvp_file_path, "w")
     WriteStringToFile(Model_rvh_string + '\n \n', Model_rvh_file_path, "w")
     WriteStringToFile(Model_rvp_string_modify + '\n \n', Model_rvp_file_path, "a")
-
+    
     Lake_rvh_string, Lake_rvh_file_path = Generate_Raven_Lake_rvh_String(
-        ncatinfo2, Raveinputsfolder, Model_Name
+        ncatinfo2, Raveinputsfolder, Model_Name,lake_out_flow_method
     )
+            
     WriteStringToFile(Lake_rvh_string, Lake_rvh_file_path, "w")
 
     if WriteObsrvt > 0:
@@ -917,9 +922,9 @@ def Generate_Raven_Channel_rvp_string_sub(
         sidwd = 0.5 * 0.5 * chwd
         zch = (chwd - botwd) / 2 / chdep
     if iscalmanningn == True:
-        mann = '{:>10.4f}'.format(channeln) #str(channeln)
+        mann = '{:>10.8f}'.format(channeln) #str(channeln)
     else:
-        mann = '{:>10.4f}'.format(0.035) #str(0.035)
+        mann = '{:>10.8f}'.format(0.035) #str(0.035)
     zfld = 4 + elev
     zbot = elev - chdep
     sidwdfp = 4 / 0.25
@@ -962,10 +967,10 @@ def Generate_Raven_Channel_rvp_string_sub(
         "    0" + tab + '{:>10.8f}'.format(floodn) #str(floodn)
     )  # orchnl.write("    0" + tab + str(floodn) +"\n")
     output_string_list.append(
-        "    " + '{:>10.4f}'.format(sidwdfp + 2 * chwd) + tab + mann #"    " + str(sidwdfp + 2 * chwd) + tab + mann
+        "    " + '{:>10.8f}'.format(sidwdfp + 2 * chwd) + tab + mann #"    " + str(sidwdfp + 2 * chwd) + tab + mann
     )  # orchnl.write("    " + str(sidwdfp + 2*chwd)+ tab + mann +"\n")
     output_string_list.append(
-        "    " + '{:>10.4f}'.format(sidwdfp + 2 * chwd + 2 * sidwd + botwd) + tab + '{:>10.8f}'.format(floodn) #"    " + str(sidwdfp + 2 * chwd + 2 * sidwd + botwd) + tab + str(floodn)
+        "    " + '{:>10.8f}'.format(sidwdfp + 2 * chwd + 2 * sidwd + botwd) + tab + '{:>10.8f}'.format(floodn) #"    " + str(sidwdfp + 2 * chwd + 2 * sidwd + botwd) + tab + str(floodn)
     )  # orchnl.write("    " + str(sidwdfp + 2*chwd + 2*sidwd + botwd)+ tab + str(floodn) +"\n")
     output_string_list.append(
         "  :EndRoughnessZones"
@@ -985,7 +990,7 @@ def Generate_Raven_Channel_rvp_string_sub(
 #########################################################################################################33
 
 
-def Generate_Raven_Lake_rvh_String(catinfo, Raveinputsfolder, Model_Name):
+def Generate_Raven_Lake_rvh_String(catinfo, Raveinputsfolder, Model_Name,lake_out_flow_method):
     """Generate string of raven lake rvh input
 
     Function that used to generate the content for
@@ -1040,6 +1045,10 @@ def Generate_Raven_Lake_rvh_String(catinfo, Raveinputsfolder, Model_Name):
     Lake_rvh_string_list.append("# by BasinMaker v2.0")
     Lake_rvh_string_list.append("#----------------------------------------------")
 
+    Gauge_col_Name = "Has_POI"
+    if "Has_POI" not in catinfo.columns:
+        Gauge_col_Name = "Has_Gauge"
+        
     for i in range(0, len(catinfo.index)):
         if catinfo.iloc[i]["HRU_IsLake"] > 0:  ## lake hru
             lakeid = int(catinfo.iloc[i]["HyLakeId"])
@@ -1049,50 +1058,130 @@ def Generate_Raven_Lake_rvh_String(catinfo, Raveinputsfolder, Model_Name):
             WeirCoe = 0.6
             hruid = int(catinfo.iloc[i]["HRU_ID"])
             Crewd = catinfo.iloc[i]["BkfWidth"]  ##3 m
+            has_obs = catinfo.iloc[i][Gauge_col_Name]  ##3 m
             #            if slakeinfo.iloc[0]['Wshd_area'] < 6000 and slakeinfo.iloc[0]['Wshd_area'] > 0:
-            Lake_rvh_string_list.append(
-                "#############################################"
-            )  # f2.write("#############################################"+"\n")
-            Lake_rvh_string_list.append(
-                "# New Lake starts"
-            )  # f2.write("###New Lake starts"+"\n")
-            Lake_rvh_string_list.append(
-                "#############################################"
-            )  # f2.write("#############################################"+"\n")
-            ######write lake information to file
-            Lake_rvh_string_list.append(
-                ":Reservoir" + "   Lake_" + str(int(lakeid))
-            )  # f2.write(":Reservoir"+ "   Lake_"+ str(int(lakeid))+ "   ######## " +"\n")
-            Lake_rvh_string_list.append(
-                "  :SubBasinID  " + str(int(catid))
-            )  # f2.write("  :SubBasinID  "+str(int(catid))+ "\n")
-            Lake_rvh_string_list.append(
-                "  :HRUID   " + str(int(hruid))
-            )  # f2.write("  :HRUID   "+str(int(hruid))+ "\n")
-            Lake_rvh_string_list.append(
-                "  :Type RESROUTE_STANDARD   "
-            )  # f2.write("  :Type RESROUTE_STANDARD   "+"\n")
-            Lake_rvh_string_list.append(
-                "  :WeirCoefficient  " + str(WeirCoe)
-            )  # f2.write("  :WeirCoefficient  "+str(WeirCoe)+ "\n")
-            Lake_rvh_string_list.append(
-                "  :CrestWidth " + '{:>10.4f}'.format(Crewd) #"{:.4f}".format(Crewd) #str(Crewd)
-            )  # f2.write("  :CrestWidth "+str(Crewd)+ "\n")
-            Lake_rvh_string_list.append(
-                "  :MaxDepth " + str(h0)
-            )  # f2.write("  :MaxDepth "+str(h0)+ "\n")
-            Lake_rvh_string_list.append(
-                "  :LakeArea    " + str(A)
-            )  # f2.write("  :LakeArea    "+str(A)+ "\n")
-            Lake_rvh_string_list.append(
-                ":EndReservoir   "
-            )  # f2.write(":EndReservoir   "+"\n")
+            if has_obs < 1 or lake_out_flow_method == 'broad_crest':
+                Lake_rvh_string_list.append(
+                    "#############################################"
+                )  # f2.write("#############################################"+"\n")
+                Lake_rvh_string_list.append(
+                    "# New Lake starts"
+                )  # f2.write("###New Lake starts"+"\n")
+                Lake_rvh_string_list.append(
+                    "#############################################"
+                )  # f2.write("#############################################"+"\n")
+                ######write lake information to file
+                Lake_rvh_string_list.append(
+                    ":Reservoir" + "   Lake_" + str(int(lakeid))
+                )  # f2.write(":Reservoir"+ "   Lake_"+ str(int(lakeid))+ "   ######## " +"\n")
+                Lake_rvh_string_list.append(
+                    "  :SubBasinID  " + str(int(catid))
+                )  # f2.write("  :SubBasinID  "+str(int(catid))+ "\n")
+                Lake_rvh_string_list.append(
+                    "  :HRUID   " + str(int(hruid))
+                )  # f2.write("  :HRUID   "+str(int(hruid))+ "\n")
+                Lake_rvh_string_list.append(
+                    "  :Type RESROUTE_STANDARD   "
+                )  # f2.write("  :Type RESROUTE_STANDARD   "+"\n")
+                Lake_rvh_string_list.append(
+                    "  :WeirCoefficient  " + str(WeirCoe)
+                )  # f2.write("  :WeirCoefficient  "+str(WeirCoe)+ "\n")
+                Lake_rvh_string_list.append(
+                    "  :CrestWidth " + '{:>10.4f}'.format(Crewd) #"{:.4f}".format(Crewd) #str(Crewd)
+                )  # f2.write("  :CrestWidth "+str(Crewd)+ "\n")
+                Lake_rvh_string_list.append(
+                    "  :MaxDepth " + str(h0)
+                )  # f2.write("  :MaxDepth "+str(h0)+ "\n")
+                Lake_rvh_string_list.append(
+                    "  :LakeArea    " + str(A)
+                )  # f2.write("  :LakeArea    "+str(A)+ "\n")
 
+                Lake_rvh_string_list.append(
+                    "  :SeepageParameters   0   0 "
+                )  # f2.write("  :LakeArea    "+str(A)+ "\n")            
+                
+                Lake_rvh_string_list.append(
+                    ":EndReservoir   "
+                )  # f2.write(":EndReservoir   "+"\n")
+            elif has_obs >= 1 and lake_out_flow_method == 'power_law':
+                Lake_rvh_string_list.append(
+                    "#############################################"
+                )  # f2.write("#############################################"+"\n")
+                Lake_rvh_string_list.append(
+                    "# New Lake starts"
+                )  # f2.write("###New Lake starts"+"\n")
+                Lake_rvh_string_list.append(
+                    "#############################################"
+                )  # f2.write("#############################################"+"\n")
+                ######write lake information to file
+                Lake_rvh_string_list.append(
+                    ":Reservoir" + "   Lake_" + str(int(lakeid))
+                )  # f2.write(":Reservoir"+ "   Lake_"+ str(int(lakeid))+ "   ######## " +"\n")
+                Lake_rvh_string_list.append(
+                    "  :SubBasinID  " + str(int(catid))
+                )  # f2.write("  :SubBasinID  "+str(int(catid))+ "\n")
+                Lake_rvh_string_list.append(
+                    "  :HRUID   " + str(int(hruid))
+                )  # f2.write("  :HRUID   "+str(int(hruid))+ "\n")
+                Lake_rvh_string_list.append(
+                    "  :Type RESROUTE_STANDARD   "
+                )  # f2.write("  :Type RESROUTE_STANDARD   "+"\n")
+                Lake_rvh_string_list.append(
+                    "  :MaxDepth " + str(h0)
+                )  # f2.write("  :MaxDepth "+str(h0)+ "\n")
+                Lake_rvh_string_list.append(
+                    "  :SeepageParameters   0   0 "
+                )  # f2.write("  :LakeArea    "+str(A)+ "\n")            
+
+                Lake_rvh_string_list.append(
+                    "  :OutflowStageRelation POWER_LAW "
+                )           
+
+                Lake_rvh_string_list.append(
+                    "  %s   %s " %(str(Crewd*2/3*(9.80616**(0.5))),str(1.5))
+                ) 
+                
+                Lake_rvh_string_list.append(
+                    "  :EndOutflowStageRelation "
+                ) 
+                            
+
+                Lake_rvh_string_list.append(
+                    "  :VolumeStageRelation POWER_LAW "
+                )           
+
+                Lake_rvh_string_list.append(
+                    "  %s   %s " %(str(A),str(1))
+                ) 
+                
+                Lake_rvh_string_list.append(
+                    "  :EndVolumeStageRelation "
+                ) 
+                
+                
+                Lake_rvh_string_list.append(
+                    "  :AreaStageRelation POWER_LAW "
+                )           
+
+                Lake_rvh_string_list.append(
+                    "  %s   %s " %(str(A),str(0))
+                ) 
+                
+                Lake_rvh_string_list.append(
+                    "  :EndAreaStageRelation "
+                ) 
+                            
+                            
+                Lake_rvh_string_list.append(
+                    ":EndReservoir   "
+                )  # f2.write(":EndReservoir   "+"\n")
+                
     Lake_rvh_string = "\n".join(Lake_rvh_string_list)
     return Lake_rvh_string, Lake_rvh_file_path
     #### write lake input files for different lake zone
 
 
+#########################
 def Return_Group_Name_Based_On_Value(value, GroupNames, Group_Thresthold_Values):
     """Return group name
     It is a function to return group name in GroupNames, based on value and
@@ -1149,6 +1238,7 @@ def Generate_Raven_Channel_rvp_rvh_String(
     SubBasinGroup_Area_Lake,
     SubBasinGroup_NM_Channel,
     SubBasinGroup_Length_Channel,
+    Tr = 1,
     aspect_from_gis = 'grass'
 ):  # Writervhchanl(ocatinfo,Raveinputsfolder,lenThres,iscalmanningn,HRU_ID_NM,HRU_Area_NM,Sub_ID_NM,Lake_As_Gauge = False,Model_Name = 'test'):
     """Generate string of raven chennel rvp input and rvh input
@@ -1287,7 +1377,6 @@ def Generate_Raven_Channel_rvp_rvh_String(
     Model_rvh_string_list.append(
         "  :Units        none           none          none           km    none"
     )  # orvh.write("  :Units        none           none          none           km    none"+"\n")
-
     catinfo_sub = catinfo.drop_duplicates(
         "SubId", keep="first"
     )  ### remove duplicated subids, beacuse of including hrus in the dataframe
@@ -1308,6 +1397,7 @@ def Generate_Raven_Channel_rvp_rvh_String(
         + "   "
         + "SubId"
     )
+    not_write_default_channel = True
     for i in range(0, len(catinfo_sub)):
         ### Get catchment width and dpeth
         catid = int(catinfo_sub["SubId"].values[i])
@@ -1341,45 +1431,78 @@ def Generate_Raven_Channel_rvp_rvh_String(
         )
         SubBasin_Group_Channel.loc[i, "SubId"] = catid
         SubBasin_Group_Channel.loc[i, "SubBasin_Group_NM"] = GroupName
+        
+        if strRlen != "ZERO-":
+            pronam = "Chn_" + Strcat
+        else:
+            pronam = "Chn_ZERO_LENGTH"
 
-        pronam = "Chn_" + Strcat
+        if strRlen != "ZERO-":
+            chslope = max(catinfo_sub["RivSlope"].values[i], min_riv_slope)
+        else:
+            chslope = 0.12345
 
-        chslope = max(catinfo_sub["RivSlope"].values[i], 0.00001)
-
-        if chslope < 0:
-            chslope = 0.0001234
-
-        if catinfo_sub["Ch_n"].values[i] > 0:
+        if strRlen != "ZERO-":
             nchn = catinfo_sub["Ch_n"].values[i]
         else:
-            nchn = 0.001234
+            nchn = 0.12345
 
-        if catinfo_sub["FloodP_n"].values[i] > 0:
+        if strRlen != "ZERO-":
             floodn = catinfo_sub["FloodP_n"].values[i]
         else:
-            floodn = 0.035
-
-        output_string_chn_rvp_sub = Generate_Raven_Channel_rvp_string_sub(
-            pronam,
-            max(catinfo_sub["BkfWidth"].values[i], 1),
-            max(catinfo_sub["BkfDepth"].values[i], 1),
-            chslope,
-            catinfo_sub["MeanElev"].values[i],
-            floodn,
-            nchn,
-            iscalmanningn,
-        )
-
+            floodn = 0.12345
+        
+        if strRlen != "ZERO-":
+            bkf_width = max(catinfo_sub["BkfWidth"].values[i], 1)
+            bkf_depth = max(catinfo_sub["BkfDepth"].values[i], 1)
+        else:
+            bkf_width = 0.12345
+            bkf_depth = 0.12345
+        
+        if strRlen != "ZERO-":
+            output_string_chn_rvp_sub = Generate_Raven_Channel_rvp_string_sub(
+                pronam,
+                bkf_width,
+                bkf_depth,
+                chslope,
+                catinfo_sub["MeanElev"].values[i],
+                floodn,
+                nchn,
+                iscalmanningn,
+            )
+        elif strRlen == "ZERO-" and not_write_default_channel:
+            output_string_chn_rvp_sub = Generate_Raven_Channel_rvp_string_sub(
+                pronam,
+                bkf_width,
+                bkf_depth,
+                chslope,
+                catinfo_sub["MeanElev"].values[i],
+                floodn,
+                nchn,
+                iscalmanningn,
+            )
+            not_write_default_channel = False
+        else:
+            output_string_chn_rvp_sub = [] 
+            output_string_chn_rvp_sub.append("#   Sub "+ Strcat + "  refer to  Chn_ZERO_LENGTH ")
+            output_string_chn_rvp_sub.append("##############new channel ##############################")
+            output_string_chn_rvp_sub = "\n".join(output_string_chn_rvp_sub)
+            
         Channel_rvp_string_list.append(output_string_chn_rvp_sub)
 
-        if catinfo_sub["Has_Gauge"].values[i] > 0:
+        Gauge_col_Name = "Has_POI"
+        if "Has_POI" not in catinfo_sub.columns:
+            Gauge_col_Name = "Has_Gauge"
+        
+        if catinfo_sub[Gauge_col_Name].values[i] > 0:
             Guage = "1"
         elif (
             catinfo_sub["Lake_Cat"].values[i] > 0 and Lake_As_Gauge == True
-        ):  # and catinfo_sub['HRU_Type'].values[i] == 1:
+        ): 
             Guage = "1"
         else:
             Guage = "0"
+        
         Model_rvh_string_list.append(
             "  "
             + Strcat
@@ -1394,10 +1517,39 @@ def Generate_Raven_Channel_rvp_rvh_String(
             + strRlen
             + tab
             + Guage
-        )  # orvh.write("  "+Strcat+tab+'sub'+Strcat+tab+StrDid+tab+pronam+tab+strRlen+tab+Guage+"\n")
+        )  
 
     Model_rvh_string_list.append(":EndSubBasins")  # orvh.write(":EndSubBasins"+"\n")
     Model_rvh_string_list.append("\n")  # orvh.write("\n")
+    ##########################################
+    
+    # Model_rvh_string_list.append(":SubBasinProperties")
+    # Model_rvh_string_list.append(":Parameters,  TIME_TO_PEAK,  TIME_CONC,   TIME_LAG,")
+    # Model_rvh_string_list.append(":Units     ,  d           ,          d,          d,")
+    # 
+    # 
+    # for i in range(0, len(catinfo_sub)):
+    #     ### Get catchment width and dpeth
+    #     catid = int(catinfo_sub["SubId"].values[i])
+    #     subarea = int(catinfo_sub["BasArea"].values[i]/1000/1000)
+    #     if (catinfo_sub["Lake_Cat"].values[i] <= 0):  
+    #         routing_area = subarea
+    #     else:
+    #         routing_area = max(0.0001,subarea - catinfo_sub["LakeArea"].values[i]/1000/1000)
+    # 
+    #     Tc = max(0.01,0.76*routing_area**0.38/24)
+    #     Tl = 0.6*Tc
+    #     Tp = Tr/2 +Tl
+    # 
+    #     Tc = '{:>10.4f}'.format(Tc)  + "," + tab
+    #     Tl = '{:>10.4f}'.format(Tl)  + "," + tab 
+    #     Tp = '{:>10.4f}'.format(Tp)  + "," + tab 
+    #     Model_rvh_string_list.append(tab + str(catid) + "," + tab + Tp + Tc + Tl)
+    # 
+    # Model_rvh_string_list.append(":EndSubBasinProperties")
+    # 
+    # Model_rvh_string_list.append("\n")  # orvh.write("\n")
+        
     ##########################################
     Model_rvh_string_list.append(":HRUs")  # orvh.write(":HRUs"+"\n")
     Model_rvh_string_list.append(
@@ -1444,6 +1596,9 @@ def Generate_Raven_Channel_rvp_rvh_String(
             if asp_temp > 360:
                 asp_temp = asp_temp - 360
             ASPECT = str(asp_temp) + tab
+        elif aspect_from_gis == 'purepy':
+            asp_temp = 360 - cataspect
+            ASPECT = str(asp_temp) + tab            
         else:
             ASPECT = '{:>10.4f}'.format(cataspect)  + tab #str(cataspect) + tab
             
