@@ -30,6 +30,15 @@ def combine_catchments_covered_by_the_same_lake_method(
             Routing_Product_Folder=Routing_Product_Folder,
         )        
 
+    if gis_platform == "purepy":
+        from basinmaker.postprocessing.combinepurepy import (
+            combine_catchments_covered_by_the_same_lake_purepy,
+        )
+
+        combine_catchments_covered_by_the_same_lake_purepy(
+            Routing_Product_Folder=Routing_Product_Folder,
+        )   
+        
 
 def simplify_routing_structure_by_filter_lakes_method(
     Path_final_riv_ply="#",
@@ -76,8 +85,23 @@ def simplify_routing_structure_by_filter_lakes_method(
             qgis_prefix_path=qgis_prefix_path,
             gis_platform=gis_platform,
         )
-        
 
+    if gis_platform == "purepy":
+        from basinmaker.postprocessing.selectlakepurepy import (
+            simplify_routing_structure_by_filter_lakes_purepy,
+        )
+
+        simplify_routing_structure_by_filter_lakes_purepy(
+            Routing_Product_Folder = Routing_Product_Folder,
+            Thres_Area_Conn_Lakes=Thres_Area_Conn_Lakes,
+            Thres_Area_Non_Conn_Lakes=Thres_Area_Non_Conn_Lakes,
+            Selected_Lake_List_in=Selected_Lake_List_in,
+            OutputFolder=OutputFolder,
+            qgis_prefix_path=qgis_prefix_path,
+            gis_platform=gis_platform,
+        )
+                
+        
 def simplify_routing_structure_by_drainage_area_method(
     Routing_Product_Folder='#',
     Area_Min=-1,
@@ -112,7 +136,16 @@ def simplify_routing_structure_by_drainage_area_method(
             OutputFolder=OutputFolder,
         )
 
+    if gis_platform == "purepy":
+        from basinmaker.postprocessing.increasedapurepy import (
+            simplify_routing_structure_by_drainage_area_purepy,
+        )
 
+        simplify_routing_structure_by_drainage_area_purepy(
+            Routing_Product_Folder = Routing_Product_Folder,
+            Area_Min=Area_Min,
+            OutputFolder=OutputFolder,
+        )
 
 def select_part_of_routing_product_method(
     Path_Points,
@@ -181,9 +214,20 @@ def select_part_of_routing_product_method(
             mostupstreamid=mostupid,
             Routing_Product_Folder = Routing_Product_Folder,
         )
+                         
+    if gis_platform == "purepy":
+        from basinmaker.postprocessing.selectprodpurepy import (
+        Select_Routing_product_based_SubId_purepy
+        )
+        Select_Routing_product_based_SubId_purepy(
+            OutputFolder=OutputFolder,
+            mostdownid=mostdownid,
+            mostupstreamid=mostupid,
+            Routing_Product_Folder = Routing_Product_Folder,
+        )
                         
     return
-
+    
 
 def generate_hrus_method(
     Path_Subbasin_Ply,
@@ -212,6 +256,8 @@ def generate_hrus_method(
     OutputFolder="#",
     qgis_prefix_path="#",
     gis_platform="qgis",
+    pixel_size = 30,
+    area_ratio_thresholds = [0,0,0]
 ):
     if gis_platform == "qgis":
         from basinmaker.postprocessing.hru import GenerateHRUS_qgis
@@ -275,6 +321,39 @@ def generate_hrus_method(
         )
 
 
+    if gis_platform == "purepy":
+        from basinmaker.postprocessing.hrupurepy import GenerateHRUS_purepy
+
+        GenerateHRUS_purepy(
+            Path_Subbasin_Ply=Path_Subbasin_Ply,
+            Landuse_info=Landuse_info,
+            Soil_info=Soil_info,
+            Veg_info=Veg_info,
+            Sub_Lake_ID=Sub_Lake_ID,
+            Sub_ID=Sub_ID,
+            Path_Connect_Lake_ply=Path_Connect_Lake_ply,
+            Path_Non_Connect_Lake_ply=Path_Non_Connect_Lake_ply,
+            Lake_Id=Lake_Id,
+            Path_Landuse_Ply=Path_Landuse_Ply,
+            Landuse_ID=Landuse_ID,
+            Path_Soil_Ply=Path_Soil_Ply,
+            Soil_ID=Soil_ID,
+            Path_Veg_Ply=Path_Veg_Ply,
+            Veg_ID=Veg_ID,
+            Path_Other_Ply_1=Path_Other_Ply_1,
+            Other_Ply_ID_1=Other_Ply_ID_1,
+            Path_Other_Ply_2=Path_Other_Ply_2,
+            Other_Ply_ID_2=Other_Ply_ID_2,
+            Inmportance_order = Inmportance_order,
+            min_hru_area_pct_sub = min_hru_area_pct_sub,
+            DEM=DEM,
+            Project_crs=Project_crs,
+            OutputFolder=OutputFolder,
+            pixel_size = pixel_size,
+            area_ratio_thresholds = area_ratio_thresholds,
+        )
+        
+
     return
 
 
@@ -336,5 +415,16 @@ def generate_area_weight_of_two_polygons(
             qgis_prefix_path = qgis_prefix_path,
         )
 
+    if gis_platform == "arcgis":
+        from basinmaker.postprocessing.gridweightarcgis import (
+            Area_Weighted_Mapping_Between_Two_Polygons_Arcgis,
+        )
+        Area_Weighted_Mapping_Between_Two_Polygons_Arcgis(
+            Target_Ply_Path=target_polygon_path,
+            Mapping_Ply_Path=mapping_polygon_path,
+            Col_NM=col_nm,
+            Output_Folder=output_folder,
+        )
+        
 
 
